ColorPickerResult class

What ColorPickerDialog resolves with.

Annotations

Constructors

ColorPickerResult.clear()
Clears the color attribute.
const
ColorPickerResult.color(Color color)
Applies color.
const

Properties

cleared bool
Whether the user chose "No color".
final
color Color?
The chosen color; null when cleared.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited