attach method
Called once when the owning controller is constructed. Use it to
register or replace services on scope and to capture per-instance
state.
Implementation
void attach(EditorScope scope) {}
Called once when the owning controller is constructed. Use it to
register or replace services on scope and to capture per-instance
state.
void attach(EditorScope scope) {}