BlockquoteSpaceShortcut class
'> ' at a line start → blockquote.
- Inheritance
-
- Object
- TypingShortcut
- SpaceShortcut
- BlockquoteSpaceShortcut
Constructors
- BlockquoteSpaceShortcut()
-
Creates the shortcut.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attributeFor(
String prefix) → Attribute< Object?> ? -
The block attribute to apply when
prefix(line start → caret, including the trailing space) matches this shortcut, ornullwhen it does not.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryApply(
QuillKitController controller, String trigger) → bool -
Attempts to apply this shortcut after
triggerwas typed; returns whether the document was changed.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited