ListStyle enum
The list styles a line can belong to, serialized as the value of the
list attribute.
Values
- ordered → const ListStyle
-
Numbered list item.
const ListStyle('ordered') - bullet → const ListStyle
-
Bulleted list item.
const ListStyle('bullet') - checked → const ListStyle
-
Checklist item in the checked state.
const ListStyle('checked') - unchecked → const ListStyle
-
Checklist item in the unchecked state.
const ListStyle('unchecked')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The string stored in Delta JSON for this list style.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited