ScriptStyle enum
Vertical position of an inline run, serialized as the value of the
script attribute.
Values
- subscript → const ScriptStyle
-
Renders below the baseline, JSON value
'sub'.const ScriptStyle('sub') - superscript → const ScriptStyle
-
Renders above the baseline, JSON value
'super'.const ScriptStyle('super')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The string stored in Delta JSON for this script style.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScriptStyle> - A constant List of the values in this enum, in order of their declaration.